@@ -12,20 +12,15 @@
 
 #include "config-plasma.h"
 
-#include <QAbstractButton>
-#include <QActionGroup>
 #include <QDebug>
 #include <QFile>
 #include <QJSEngine>
 #include <QList>
-#include <QMessageBox>
 #include <QMetaEnum>
 
 #include <KAuthorized>
-#include <KColorScheme>
 #include <KConfigLoader>
 #include <KConfigPropertyMap>
-#include <KDesktopFile>
 #include <KGlobalAccel>
 #include <KLocalizedString>
 #include <KPackage/Package>
@@ -40,7 +35,6 @@
 
 #include <cmath>
 #include <limits>
-#include <qaction.h>
 
 namespace Plasma
 {
@@ -63,7 +57,6 @@ Applet::Applet(QObject *parentObject, const KPluginMetaData &data, const QVarian
     // WARNING: do not access config() OR globalConfig() in this method!
     //          that requires a scene, which is not available at this point
     d->init(args.mid(2));
-    d->setupPackage();
 }
 
 Applet::~Applet()
